import React, { useState, useEffect } from 'react';
import { Modal, Space, Tooltip } from 'antd';
import TableView from '@/components/TableView';
import * as $$ from '@/utils/utility';
import './index.less';

// 获取模板列表
function getTemplateListApi(params) {
  return $$.ax.request({ 
    url: '/sy/template/page', 
    type: 'get',
    data: params,
    service: 'mediate' 
  });
}

const TemplateChoose = ({ 
  visible = false, 
  onCancel, 
  onSelect,
  type = '' 
}) => {
  const [templateList, setTemplateList] = useState([]);
  const [pagination, setPagination] = useState({
    current: 1,
    pageSize: 10,
    total: 0,
    tempType: type
  });

  // 获取模板列表
  const getTemplateList = async (params = {}) => {
    const res = await getTemplateListApi({
      page: pagination.current,
      size: pagination.pageSize,
      businessType:pagination.tempType,
      templateType:2,
      ...params
    });
    if (res.type) {
      setTemplateList(res.data.records.map((item, index) => ({
        ...item,
        indexNo: (pagination.current - 1) * pagination.pageSize + index + 1
      })));
      setPagination({
        ...pagination,
        total: res.data.total
      });
    }
  };

  useEffect(() => {
    if (visible) {
      getTemplateList();
    }
  }, [visible, pagination.current, pagination.pageSize]);

  // 表格列定义
  const templateColumns = [
    {
      title: '序号',
      dataIndex: 'indexNo',
      width: 50,
    },
    {
      title: '类型',
      dataIndex: 'templateType',
      width: 50,
    },
    {
      title: '模板名称',
      dataIndex: 'templateName',
      width: 100,
    },
    {
      title: '模板内容',
      dataIndex: 'templateContent',
      width: 500,
      render: (text, record) => {
        return (
          <div className="template-content">
            <div className="content-text">
              {text}
            </div>
            <div className="view-more-row">
              <span 
                className="view-more" 
                onClick={(e) => {
                  e.stopPropagation();
                  Modal.confirm({
                    title: (
                      <div className="modal-title-wrapper">
                        <div className="modal-title-label">模板</div>
                        <div className="template-name">{record.templateName}</div>
                      </div>
                    ),
                    content: (
                      <div className="template-detail-content">
                        <div className="template-text">{text}</div>
                      </div>
                    ),
                    width: 400,
                    className: 'template-detail-modal',
                    icon: null,
                    cancelText: '关闭',
                    okText: '使用',
                    okButtonProps: {
                      className: 'confirm-ok-btn'
                    },
                    cancelButtonProps: {
                      className: 'confirm-cancel-btn'
                    },
                    onOk: () => {
                      onSelect && onSelect(record);
                      onCancel && onCancel();
                    }
                  });
                }}
              >
                ...查看更多
              </span>
            </div>
          </div>
        );
      }
    },
    {
      title: '操作',
      width: 80,
      fixed: 'right',
      render: (_, record) => (
        <Space>
          <div 
            onClick={() => {
              onSelect && onSelect(record);
              onCancel && onCancel();
            }} 
            className="operate-link"
          >
            使用
          </div>
        </Space>
      )
    },
  ];

  return (
    <Modal
      title="选择模版"
      open={visible}
      onCancel={onCancel}
      width={938}
      style={{ 
        top: 100,
      }}
      footer={null}
      destroyOnClose
      bodyStyle={{
        padding: '12px 24px',
        maxHeight: '600px'
      }}
    >
      <TableView
        columns={templateColumns}
        dataSource={templateList}
        rowKey="id"
        pagination={{
          ...pagination,
          onChange: (page, pageSize) => {
            setPagination({
              ...pagination,
              current: page,
              pageSize
            });
          }
        }}
        scroll={{ y: 260 }}
        style={{
          marginTop: -8
        }}
      />
    </Modal>
  );
};

export default TemplateChoose;